Usage
bfgs_gcv.ubre(fn=gcv.ubre_grad, rho, ini.fd=TRUE, G, gamma=1, env,
n.pen=length(rho), typx=rep(1,n.pen), typf=1,
steptol= 1e-7, gradtol = 6.0554*1e-06, maxNstep = 5,
maxHalf = 30, check.analytical, del)Arguments
fn
GCV/UBRE Function which returs the GCV/UBRE value and its derivative wrt log smoothing parameter.
rho
log of the initial values of the smoothing parameters.
ini.fd
If TRUE, a finite difference to the Hessian is used to find the initial
inverse Hessian, otherwise the initial
inverse Hessian is a diagonal matrix `100*I'.
G
A list of items needed to fit a SCAM.
gamma
An ad hoc parametrer of the GCV/UBRE score.
env
Get the enviroment for the model coefficients, their derivatives and the smoothing parameter.
n.pen
Smoothing parameter dimension.
typx
A vector whose component is a positive scalar specifying the typical magnitude of sp.
typf
A positive scalar estimating the magnitude of the gcv near the minimum.
steptol
A positive scalar giving the tolerance at which the scaled distance between
two successive iterates is considered close enough to zero to terminate the algorithm.
gradtol
A scalar giving a tolerance at which the gradient is considered
to be close enougth to 0 to terminate the algorithm.
maxNstep
A positive scalar which gives the maximum allowable step length.
maxHalf
A positive scalar which gives the maximum number of step halving
in "backtracking".
check.analytical
If this is TRUE then finite difference derivatives of GCV/UBRE score will be calculated.
del
A positive scalar (default is 1e-4) giving an increment for finite difference approximation when
check.analytical=TRUE.