Arguments
rho
log of the initial values of the smoothing parameters.
G
a list of items needed to fit a SCAM.
gamma
A constant multiplier to inflate the model degrees of freedom in the GCV or UBRE/AIC score.
env
Get the enviroment for the model coefficients, their derivatives and the smoothing parameter.
check.analytical
If this is TRUE then finite difference derivatives of GCV/UBRE score will be calculated,
otherwise NULL.
del
A positive scalar (default is 1e-4) giving an increment for finite difference approximation when
check.analytical=TRUE, otherwise NULL.