Usage
scam.fit(G,sp, ee,eb,esp, maxit=200, devtol=1e-8, steptol=1e-8, start=NULL,
etastart=NULL, mustart=NULL)Arguments
G
A list of items needed to fit a SCAM.
sp
The vector of smoothing parameters.
ee
Get the enviroment for the model coefficients.
eb
Get the enviroment for the model coefficients derivatives.
esp
Get the enviroment for the smoothing parameter.
maxit
Maximum iterations in the Newton-Raphson procedure.
devtol
A positive scalar giving the tolerance at which the scaled distance between
two successive penalized deviances is considered close enough to zero to terminate the algorithm.
steptol
A positive scalar giving the tolerance at which the scaled distance between
two successive iterates is considered close enough to zero to terminate the algorithm.
start
Initial values for the model coefficients
etastart
Initial values for the linear predictor
mustart
Initial values for the expected values