Usage
scam.fit(G, sp, maxit=200, devtol=1e-8, steptol=1e-8, gamma=1, start=NULL,
etastart=NULL, mustart=NULL, env = env)Arguments
G
A list of items needed to fit a SCAM.
sp
The vector of smoothing parameters.
env
Get the enviroment for the model coefficients, their derivatives and the smoothing parameter.
maxit
Maximum iterations in the Newton-Raphson procedure.
devtol
A positive scalar giving the tolerance at which the scaled distance between
two successive penalized deviances is considered close enough to zero to terminate the algorithm.
steptol
A positive scalar giving the tolerance at which the scaled distance between
two successive iterates is considered close enough to zero to terminate the algorithm.
gamma
This constant allows to inflate the model degrees of
freedom in the GCV or UBRE/AIC score.
start
Initial values for the model coefficients
etastart
Initial values for the linear predictor
mustart
Initial values for the expected values